<?php
/***************************************************************
 * Copyright notice
 *
 * (c) 2012 - 2013 Michael Staatz <mstaatz@me.com>
 * All rights reserved
 *
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 *
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

require_once t3lib_extMgm::extPath('markdown_content', 'lib/DropPHP/DropboxClient.php');

/**
 * update class
 */
class ext_update {
	protected $localLang = 'LLL:EXT:markdown_content/lang/locallang.xml:updater.';

	public function access($what = 'all') {
		$registry = t3lib_div::makeInstance('t3lib_registry');
		$dropBoxKey = $registry->get('tx_markdown_content_dropbox', 'access_token');
		if ($dropBoxKey === NULL) {
			return TRUE;
		} else {
			return TRUE;
		}
	}

	public function main() {
		$extConf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['markdown_content']);
		if (empty($extConf['dropBoxAppKey']) || empty($extConf['dropBoxAppSecret'])) {
			$flashMessage = t3lib_div::makeInstance(
				't3lib_FlashMessage',
				$this->translate('error.no_ext_conf.message'),
				$this->translate('error.no_ext_conf.title'),
				t3lib_FlashMessage::ERROR
			);
			return $flashMessage->render();
		}

		$dropbox = new DropboxClient(
			array(
				'app_key' => $extConf['dropBoxAppKey'], 
				'app_secret' => $extConf['dropBoxAppSecret'],
				'app_full_access' => (int) $extConf['dropBoxAppTypeFull'],
			),
			'en'
		);

		$registry = t3lib_div::makeInstance('t3lib_registry');

		if ((int) t3lib_div::_GP('do_unlink_dropbox') === 1) {
			$registry->removeAllByNamespace('tx_markdown_content_dropbox');
		}

		$request_token = $registry->get('tx_markdown_content_dropbox', 'request_token');
		if ($request_token === NULL) {
			$auth_url = $dropbox->BuildAuthorizeUrl();
			$request_token = $dropbox->GetRequestToken();
			$registry->set('tx_markdown_content_dropbox', 'request_token', $request_token);

			$flashMessage = t3lib_div::makeInstance(
				't3lib_FlashMessage',
				$this->translate('error.authorize_dropbox.message'),
				$this->translate('error.authorize_dropbox.title'),
				t3lib_FlashMessage::INFO
			);
			$url = t3lib_div::linkThisScript();
			$content = $flashMessage->render();
			$content .= '
			<dl>
				<dt>&nbsp;</dt>
				<dd>&nbsp;</dd>
				<dt><strong>' . $this->translate('authorize_dropbox.link_info') . '</strong></dt>
				<dd><a href="' . $auth_url . '" target="_blank">' . $auth_url . '</a></dd>
			</dl>
			<br/>
			<form action="' . $url . '" method="POST">
				<input type="hidden" name="do_authorize" value="1" />
				<input type="submit" value="' . $this->translate('authorize_dropbox.submit') . '" />
			</form>
			';

			return $content;
		}

		if ((int) t3lib_div::_GP('do_authorize') === 1) {
			$access_token = $dropbox->GetAccessToken($request_token);
			$registry->set('tx_markdown_content_dropbox', 'access_token', $access_token);
		}

		$content = '';
		$buttontext = $this->translate('authorize_dropbox.reset');
		$access_token = $registry->get('tx_markdown_content_dropbox', 'access_token');
		if ($access_token['t'] !== NULL) {
			$dropbox->SetAccessToken($access_token);

			$flashMessage = t3lib_div::makeInstance(
				't3lib_FlashMessage',
				$this->translate('finish.authorize_dropbox.message'),
				$this->translate('finish.authorize_dropbox.title'),
				t3lib_FlashMessage::OK
			);
			$content .= $flashMessage->render();

			$accountInfo = $dropbox->GetAccountInfo();
			$content .= '<br/><p>display name: ' . $accountInfo->display_name . '</p>';
			$content .= '<p>uid: ' . $accountInfo->uid . '</p>';
			$content .= '<p>country: ' . $accountInfo->country . '</p>';
			$content .= '<p>quota_info / shared: ' . $accountInfo->quota_info->shared . '</p>';
			$content .= '<p>quota_info / quota: ' . $accountInfo->quota_info->quota . '</p>';
			$content .= '<p>quota_info / normal: ' . $accountInfo->quota_info->normal . '</p>';
			
			$buttontext = $this->translate('authorize_dropbox.unlink');
		}
		$content .= '<br/><br/>
			<form action="' . $url . '" method="POST">
				<input type="hidden" name="do_unlink_dropbox" value="1" />
				<input type="submit" value="' . $buttontext . '" />
			</form>';

		return $content;
	}

	/**
	 * Get the localized string for an given key
	 *
	 * @param string $key
	 * @return string
	 */
	protected function translate($key) {
		return $GLOBALS['LANG']->sL($this->localLang . $key);
	}
}

?>